"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.mockComponents = mockComponents;
exports.modifyMockedComponents = modifyMockedComponents;
function _compiler() {
  const data = require("@teambit/compiler");
  _compiler = function () {
    return data;
  };
  return data;
}
function _harmonyTesting() {
  const data = require("@teambit/harmony.testing.load-aspect");
  _harmonyTesting = function () {
    return data;
  };
  return data;
}
function _workspace() {
  const data = require("@teambit/workspace");
  _workspace = function () {
    return data;
  };
  return data;
}
function _install() {
  const data = require("@teambit/install");
  _install = function () {
    return data;
  };
  return data;
}
function _fsExtra() {
  const data = _interopRequireDefault(require("fs-extra"));
  _fsExtra = function () {
    return data;
  };
  return data;
}
function _pMapSeries() {
  const data = _interopRequireDefault(require("p-map-series"));
  _pMapSeries = function () {
    return data;
  };
  return data;
}
function _path() {
  const data = _interopRequireDefault(require("path"));
  _path = function () {
    return data;
  };
  return data;
}
function _tracker() {
  const data = require("@teambit/tracker");
  _tracker = function () {
    return data;
  };
  return data;
}
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
/**
 * create dummy components, add, link and compile them.
 * if `numOfComponents` is more than one, the components will depend on each other. by default, it's one.
 */
async function mockComponents(workspacePath, {
  numOfComponents = 1,
  additionalStr = ''
} = {}) {
  const compsDirs = await createComponents(workspacePath, {
    numOfComponents,
    additionalStr
  });
  const harmony = await (0, _harmonyTesting().loadManyAspects)([_workspace().WorkspaceAspect, _tracker().TrackerAspect, _install().InstallAspect, _compiler().CompilerAspect], workspacePath);
  const workspace = harmony.get(_workspace().WorkspaceAspect.id);
  const tracker = harmony.get(_tracker().TrackerAspect.id);
  const results = await (0, _pMapSeries().default)(compsDirs, async compDir => {
    const {
      componentId
    } = await tracker.track({
      rootDir: compDir
    });
    return {
      id: componentId,
      dir: compDir
    };
  });
  await workspace.bitMap.write();
  const install = harmony.get(_install().InstallAspect.id);
  await install.link({
    rewire: true
  });
  const compiler = harmony.get(_compiler().CompilerAspect.id);
  await compiler.compileOnWorkspace();
  return results;
}

/**
 * make the mocked components modified by appending the `additionalStr` to the component files
 */
async function modifyMockedComponents(workspacePath, additionalStr = ' ', {
  numOfComponents = 1
} = {}) {
  await createComponents(workspacePath, {
    numOfComponents,
    additionalStr
  });
}
async function createComponents(workspacePath, {
  numOfComponents = 1,
  additionalStr = ''
} = {}) {
  const getImp = index => {
    if (index === numOfComponents) return `module.exports = () => 'comp${index}${additionalStr}';`;
    const nextComp = `comp${index + 1}`;
    return `const ${nextComp} = require('../${nextComp}');
module.exports = () => 'comp${index}${additionalStr} and ' + ${nextComp}();`;
  };
  const numOfComponentsArr = Array(numOfComponents).fill(null);
  return (0, _pMapSeries().default)(numOfComponentsArr, async (val, key) => {
    const i = key + 1;
    const compDir = _path().default.join(workspacePath, `comp${i}`);
    await _fsExtra().default.outputFile(_path().default.join(compDir, `index.js`), getImp(i));
    return compDir;
  });
}

//# sourceMappingURL=mock-components.js.map